<?php
/**
 * Contains location SEO page template.
 *
 * @since 1.0.0
 * @since 1.4.2 Customized by using pagination and search filter.
 * @package GeoDirectory_Location_Manager
 *
 * @global object $wpdb WordPress Database object.
 * @global string $table_prefix WordPress Database Table prefix.
 */
global $wpdb, $table_prefix;

$table_prefix = $wpdb->prefix;

$get_countries = $wpdb->get_results("select * from ".POST_LOCATION_TABLE." GROUP BY country ORDER BY country ASC");

$location_type = !empty($_REQUEST['gd_loc']) && in_array($_REQUEST['gd_loc'], array('country', 'region', 'city')) ? $_REQUEST['gd_loc'] : 'country';

$args = array();
$args['location_type'] = $location_type;

$data = geodir_location_seo_settings_list($args);

$items = !empty($data) && !empty($data['items']) ? $data['items'] : NULL;
//echo '<pre>items : '; print_r( $items ); echo '</pre>';

if ($location_type == 'city') {
	$location_type_label = __('Cities', 'geodirlocation');
	$location_label = __('City', 'geodirlocation');
} else if ($location_type == 'region') {
	$location_type_label = __('Regions', 'geodirlocation');
	$location_label = __('Region', 'geodirlocation');
} else {
	$location_type_label = __('Countries', 'geodirlocation');
	$location_label = __('Country', 'geodirlocation');
}
?>
<div class="gd-content-heading gd-location-seo-box">
	<h3><?php echo __('Geo Directory Manage SEO', 'geodirlocation') . '&nbsp;&nbsp;&raquo;&nbsp;&nbsp;' . $location_type_label; ?></h3>
	<?php if ( !empty( $data['pagination_top'] ) || !empty( $data['filter_box'] ) ) { ?>
	<br class="clear" />
	<div class="tablenav top">
		<div class="alignleft actions bulkactions gd-seo-bulkactions"><?php if ( !empty( $data['filter_box'] ) ) { echo $data['filter_box']; } ?></div>
		<?php if ( !empty( $data['pagination_top'] ) ) { echo $data['pagination_top']; } ?>
	</div><br class="clear" />
	<?php } ?>
	<table id="geodir_location_seo_settings" style="width:100%" cellpadding="5" class="widefat post fixed gd-seo-tbltype-<?php echo $location_type;?>">
		<thead>
			<tr>
				<th align="left"><strong><?php echo __('Location', 'geodirlocation') . ' <small>(' . $location_label . ')</small>';?></strong></th>
				<?php if ($location_type == 'region' || $location_type == 'city') { ?>
				<?php if ($location_type == 'city') { ?>
				<th align="left"><strong><?php _e('Region', 'geodirlocation');?></strong></th>
				<?php } ?>
				<th align="left"><strong><?php _e('Country', 'geodirlocation');?></strong></th>
				<?php } ?>
				<th align="left" class="gd-seo-metath"><strong><?php _e('Meta Description', 'geodirlocation');?></strong></th>
				<th align="left" class="gd-seo-metath"><strong><?php _e('Location Description', 'geodirlocation');?></strong></th>
			</tr>
		<?php if ($items) { ?>
		<?php
		$c = 0;
		foreach ($items as $item) {
			$meta_desc = '';
			$location_desc = '';
			$country_slug = '';
			$region_slug = '';
			$city_slug = '';
			$city_meta = '';
			
			if ($location_type == 'city') {
				$slug = $item->city_slug;
				$region_slug = $item->region_slug;
				$country_slug = $item->country_slug;
				$location_title = $item->city;
				
				$city_meta = geodir_city_info_by_slug($slug, $country_slug, $region_slug);
			} else if ($location_type == 'region') {
				$slug = $item->region_slug;
				$country_slug = $item->country_slug;
				$location_title = $item->region;
			} else {
				$slug = $item->country_slug;
				$location_title = __($item->country, 'geodirectory');
			}
			
			$meta_desc_default = $location_title;
			$location_desc_default = $location_title;
			
			$seo = geodir_location_seo_by_slug($slug, $location_type, $country_slug, $region_slug);
			if (!empty($seo)) {
				$meta_desc = $seo->seo_title != '' ? $seo->seo_title : $meta_desc;
				$location_desc = $seo->seo_desc != '' ? $seo->seo_desc : $location_desc;
			}
			
			if (!empty($city_meta)) {
				$meta_desc = $city_meta->city_meta;
				$location_desc = $city_meta->city_desc;
			}
		?>
		<tr class="geodir_set_location_seo">
			<td><?php echo $location_title;?><input type="hidden" name="gd_seo[<?php echo $c;?>][location_slug]" value="<?php echo esc_attr($slug);?>" /></td>
			<?php if ($location_type == 'region' || $location_type == 'city') { ?>
			<?php if ($location_type == 'city') { ?>
			<td><?php echo $item->region;?><input type="hidden" name="gd_seo[<?php echo $c;?>][region_slug]" value="<?php echo esc_attr($item->region_slug);?>" /></td>
			<?php } ?>
			<td><?php _e($item->country, 'geodirlocation');?><input type="hidden" name="gd_seo[<?php echo $c;?>][country_slug]" value="<?php echo esc_attr($item->country_slug);?>" /></td>
			<?php } ?>
			<td><textarea name="gd_seo[<?php echo $c;?>][meta_desc]" class="geodir_meta_keyword" placeholder="<?php esc_attr_e($meta_desc_default);?>"><?php echo stripslashes_deep($meta_desc); ?></textarea></td>
			<td><textarea name="gd_seo[<?php echo $c;?>][loc_desc]" class="geodir_meta_description" placeholder="<?php esc_attr_e($location_desc_default);?>"><?php echo stripslashes_deep($location_desc); ?></textarea></td>
		</tr>
		<?php $c++; } } ?>
		</thead>
	</table>
	<?php if ( !empty( $data['pagination'] ) ) { ?>
	<div class="tablenav bottom">
		<div class="alignleft actions bulkactions"></div>
		<?php echo $data['pagination']; ?>
		<br class="clear" />
	</div>
	<?php } ?>
</div>
<p class="submit"><input name="save" class="button-primary" type="submit" value="<?php _e( 'Save changes', 'geodirlocation' ); ?>" /><input type="hidden" name="location_ajax_action" value="geodir_set_location_seo"></p>